import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';

class TileData {
  Widget leading;
  String title;
  String subtitle;
  Widget trailing;
  bool enabled;
  bool selected;

  TileData(
      {this.leading,
      this.title,
      this.subtitle,
      this.trailing,
      this.enabled = true,
      this.selected = false});
}

class ListTileParameters {
  final bool isThreeLine;
  final bool dense;
  final EdgeInsetsGeometry contentPadding;
  final GestureTapCallback onTap;
  final GestureLongPressCallback onLongPress;

  ListTileParameters({
    this.isThreeLine = false,
    this.dense,
    this.contentPadding,
    this.onTap,
    this.onLongPress,
  });
}

class CustomDividerParameters {
  final double height;
  final double thickness;
  final double indent;
  final double endIndent;
  final Color color;

  const CustomDividerParameters({
    this.height,
    this.thickness,
    this.indent,
    this.endIndent,
    this.color,
  });
}

class CustomToolTipData {
  final String message;
  final Widget child;

  const CustomToolTipData({this.message, this.child});
}

class CustomToolTipParameters {
  final double height;
  final EdgeInsetsGeometry padding;
  final EdgeInsetsGeometry margin;
  final double verticalOffset;
  final bool preferBelow;
  final bool excludeFromSemantics;
  final Decoration decoration;
  final TextStyle textStyle;
  final Duration waitDuration;
  final Duration showDuration;

  const CustomToolTipParameters(
    CustomToolTipData data, {
    this.height,
    this.padding,
    this.margin,
    this.verticalOffset,
    this.preferBelow,
    this.excludeFromSemantics,
    this.decoration,
    this.textStyle,
    this.waitDuration,
    this.showDuration,
  });
}

class CustomLinearProgressBarParameters {
  final double value;
  final Color backgroundColor;
  final Animation<Color> valueColor;
  final String semanticsLabel;
  final String semanticsValue;

  const CustomLinearProgressBarParameters({
    Key key,
    this.value,
    this.backgroundColor,
    this.valueColor,
    this.semanticsLabel,
    this.semanticsValue,
  });
}

class Products {
  String imagepath;
  String Text1;
  String Text2;
  String Text3;
  String Text4;

  Products(this.imagepath, this.Text1, this.Text2, this.Text3, this.Text4);
}

class ListItems {
  IconData icon;
  String Text1;

  ListItems(this.icon, this.Text1);
}

class User {
  String imagepath;
  String username;
  String useremailid;
  FontWeight fontWeight;
  double fontSize;
  Color fontColor;
  Color headerColor;

  User(this.imagepath, this.username, this.useremailid, this.fontColor,
      this.fontWeight, this.fontSize, this.headerColor);
}

class ButtonBarParameters {
  String text;
  Icon icons;

  ButtonBarParameters(this.text, this.icons);
}

class TabBarParameters {
  String text;
  Icon icons;

  TabBarParameters(this.text, this.icons);
}

class TabBarProducts {
  String text;
  IconData icons;
  Widget widget;

  TabBarProducts(this.text, this.icons, this.widget);
}

class MaterialCardData {
  String imgPath;
  String title;
  String subtitle;
  String btnText;
  Icon icon;
  double height;
  double width;

  MaterialCardData(
      {@required this.imgPath,
      @required this.title,
      @required this.subtitle,
      @required this.btnText,
      @required this.icon,
      @required this.height,
      @required this.width});
}

class AppBarParameters {
  final Widget leading;
  final bool automaticallyImplyLeading;
  final Widget title;
  final List<Widget> actions;
  final Widget flexibleSpace;
  PreferredSizeWidget bottom;
  final double elevation;
  final ShapeBorder shape;
  final Color backgroundColor;
  final Brightness brightness;
  final IconThemeData iconTheme;
  final IconThemeData actionsIconTheme;
  final TextTheme textTheme;
  final bool primary;
  final bool centerTitle;
  final bool excludeHeaderSemantics;
  final double titleSpacing;
  final double toolbarOpacity;
  final double bottomOpacity;
  Widget searchBar;

  AppBarParameters(
      {this.leading,
      this.automaticallyImplyLeading,
      this.title,
      this.actions,
      this.flexibleSpace,
      this.bottom,
      this.elevation,
      this.shape,
      this.backgroundColor,
      this.brightness,
      this.iconTheme,
      this.actionsIconTheme,
      this.textTheme,
      this.primary,
      this.centerTitle,
      this.excludeHeaderSemantics,
      this.titleSpacing,
      this.toolbarOpacity,
      this.bottomOpacity,
      this.searchBar});
}

class SliverAppBarParameters {
  final Widget leading;
  final bool automaticallyImplyLeading;
  final Widget title;
  final List<Widget> actions;
  final Widget flexibleSpace;
  PreferredSizeWidget bottom;
  final double elevation;
  final bool forceElevated;
  final Color backgroundColor;
  final Brightness brightness;
  final IconThemeData iconTheme;
  final IconThemeData actionsIconTheme;
  final TextTheme textTheme;
  final bool primary;
  final bool centerTitle;
  final bool excludeHeaderSemantics;
  final double titleSpacing;
  final double expandedHeight;
  final bool floating;
  final bool pinned;
  final bool snap;
  final bool stretch;
  final double stretchTriggerOffset;
  final AsyncCallback onStretchTrigger;
  final ShapeBorder shape;

  SliverAppBarParameters(
      {this.leading,
      this.automaticallyImplyLeading,
      this.title,
      this.actions,
      this.flexibleSpace,
      this.bottom,
      this.elevation,
      this.forceElevated,
      this.backgroundColor,
      this.brightness,
      this.iconTheme,
      this.actionsIconTheme,
      this.textTheme,
      this.primary,
      this.centerTitle,
      this.excludeHeaderSemantics,
      this.titleSpacing,
      this.expandedHeight,
      this.floating,
      this.pinned,
      this.snap,
      this.stretch,
      this.stretchTriggerOffset,
      this.onStretchTrigger,
      this.shape});
}

class CustomCompositeCardParameters {
  int flexColumn1;
  int flexColumn2;
  String title;
  String subtitle;
  List<Widget> leftHandWidgets;
  List<Widget> rightHandWidgets;
  double margin;
  double elevation;
  Color cardColor;
  Color shadowColor;
  double shadowSpread;
  double textSpacing;

  CustomCompositeCardParameters(
      {this.flexColumn1,
      this.flexColumn2,
      this.title,
      this.subtitle,
      this.leftHandWidgets,
      this.rightHandWidgets,
      this.margin,
      this.elevation,
      this.cardColor,
      this.shadowColor,
      this.shadowSpread,
      this.textSpacing});
}

class MaterialChipData {
  String labelText;
  String tooltipMsg;
  String deleteMsg;
  VoidCallback callbackOnSelected;

  MaterialChipData(
      {@required this.labelText,
      @required this.tooltipMsg,
      @required this.deleteMsg,
      this.callbackOnSelected});
}

class SliderContents {
  int divs;
  double maximum;
  double minimum;
  Color colorActive;

  SliderContents(this.divs, this.maximum, this.minimum, this.colorActive);
}

class SliderParameters {
  final String label;
  final Color activeColor;
  final int divisions;
  final Color inactiveColor;
  final double max;
  final double min;
  final ValueChanged<double> onChanged;
  final ValueChanged<double> onChangeEnd;
  final ValueChanged<double> onChangeStart;
  final SemanticFormatterCallback semanticFormatterCallback;
  final double value;
  SliderParameters({
    Key key,
    this.label,
    this.activeColor,
    this.divisions,
    this.inactiveColor,
    this.max,
    this.min,
    this.onChanged,
    this.onChangeEnd,
    this.onChangeStart,
    this.semanticFormatterCallback,
    this.value,
  });
}

class AlertDialogContents {
  FlatButton Accept_Button;
  FlatButton Cancel_Button;
  String Content;
  Widget title;

  AlertDialogContents(
      this.Accept_Button, this.Cancel_Button, this.Content, this.title);
}

class AlertDialogParameters {
  final Widget title;
  final EdgeInsetsGeometry titlePadding;
  final TextStyle titleTextStyle;
  final Widget content;
  final EdgeInsetsGeometry contentPadding;
  final TextStyle contentTextStyle;
  final List<Widget> actions;
  final EdgeInsetsGeometry actionsPadding;
  final VerticalDirection actionsOverflowDirection;
  final double actionsOverflowButtonSpacing;
  final EdgeInsetsGeometry buttonPadding;
  final Color backgroundColor;
  final double elevation;
  final String semanticLabel;
  final EdgeInsets insetPadding;
  final Clip clipBehavior;
  final ShapeBorder shape;
  final bool scrollable;

  AlertDialogParameters({
    Key key,
    this.title,
    this.titlePadding,
    this.titleTextStyle,
    this.content,
    this.contentPadding = const EdgeInsets.fromLTRB(24.0, 20.0, 24.0, 24.0),
    this.contentTextStyle,
    this.actions,
    this.actionsPadding = EdgeInsets.zero,
    this.actionsOverflowDirection,
    this.actionsOverflowButtonSpacing,
    this.buttonPadding,
    this.backgroundColor,
    this.elevation,
    this.semanticLabel,
    this.insetPadding,
    this.clipBehavior = Clip.none,
    this.shape,
    this.scrollable = false,
  });
}

class BottomSheetContents {
  IconButton IconB;
  String Text1;

  BottomSheetContents(this.IconB, this.Text1);
}

class BottomSheetParameters {
  final AnimationController animationController;
  final bool enableDrag;
  final Color backgroundColor;
  final double elevation;
  final ShapeBorder shape;
  final Clip clipBehavior;
  final VoidCallback onClosing;
  final WidgetBuilder builder;

  BottomSheetParameters({
    Key key,
    this.animationController,
    this.enableDrag = true,
    this.backgroundColor,
    this.elevation,
    this.shape,
    this.clipBehavior,
    this.onClosing,
    this.builder,
  });
}

class SwitchContents {
  Color color_active_track;
  Color color_active;

  SwitchContents(this.color_active, this.color_active_track);
}

class SwitchParameters {
  final ImageProvider activeThumbImage;
  final Color activeColor;
  final Color activeTrackColor;
  final Color focusColor;
  final Color hoveColor;
  final Color inactiveTrackColor;
  final bool autofocus;
  final FocusNode focusNode;
  final ImageProvider inactiveThumbImage;
  final MaterialTapTargetSize materialTapTargetSize;
  final ImageErrorListener onActiveThumbImageError;
  final ValueChanged<bool> onChanged;
  final ImageErrorListener onInactiveThumbImageError;
  final bool value;

  SwitchParameters({
    Key key,
    this.activeThumbImage,
    @required this.activeColor,
    this.materialTapTargetSize,
    this.focusNode,
    this.autofocus,
    this.onChanged,
    this.value,
    @required this.activeTrackColor,
    this.focusColor,
    this.hoveColor,
    this.inactiveThumbImage,
    this.inactiveTrackColor,
    this.onActiveThumbImageError,
    this.onInactiveThumbImageError,
  });
}

class TextFieldContents {
  int maximum_length;
  bool maximum_length_enforced;
  bool obsecure_text;
  //Icon prefix_icon;

  TextFieldContents(
      this.maximum_length, this.maximum_length_enforced, this.obsecure_text);
}

class TextFieldParameters {
  final bool autocorrect;
  final bool autofocus;
  final InputCounterWidgetBuilder buildCounter;
  final TextEditingController controller;
  final Color cursorColor;
  final Radius cursorRadius;
  final double cursorWidth;
  final InputDecoration decoration;
  final bool enabled;
  final bool enableInteractiveSelection;
  final bool enableSuggestions;
  final bool expands;
  final FocusNode focusNode;
  final Brightness keyboardAppearances;
  final TextInputType keyboardType;
  final int maxLength;
  final bool maxLengthEnforced;
  final int maxLines;
  final int minLines;
  final bool obsecureText;
  final ValueChanged<String> onChanged;
  final VoidCallback onEditingComplete;
  final ValueChanged<String> onSubmitted;
  final GestureTapCallback onTap;
  final bool readOnly;
  final ScrollController scrollController;
  final EdgeInsets scrollPadding;
  final ScrollPhysics scrollPhysics;
  final bool selectionEnabled;
  final bool showCursor;
  final StrutStyle strutStyle;
  final TextStyle style;
  final TextAlign textAlign;
  final TextAlignVertical textAlignVertical;
  final TextCapitalization textCapitalization;
  final TextDirection textDirection;
  final TextInputAction textInputAction;
  final ToolbarOptions toolbarOptions;

  TextFieldParameters({
    Key key,
    this.toolbarOptions,
    this.textInputAction,
    this.textDirection,
    this.textCapitalization,
    this.textAlignVertical,
    this.textAlign,
    this.style,
    this.strutStyle,
    this.scrollPhysics,
    this.scrollController,
    this.focusNode,
    this.decoration,
    this.controller,
    this.onChanged,
    this.autocorrect,
    this.autofocus,
    this.buildCounter,
    this.cursorColor,
    this.cursorRadius,
    this.cursorWidth,
    this.enabled,
    this.enableInteractiveSelection,
    this.enableSuggestions,
    this.expands,
    this.keyboardAppearances,
    this.keyboardType,
    this.maxLength,
    this.maxLengthEnforced,
    this.maxLines,
    this.minLines,
    this.obsecureText,
    this.onEditingComplete,
    this.onSubmitted,
    this.onTap,
    this.readOnly,
    this.scrollPadding,
    this.selectionEnabled,
    this.showCursor,
  });
}

class CustomTileData {
  Widget leading;
  String title;
  String subtitle;
  String trailingTopText;
  String trailingBottomText;
  bool enabled;
  bool selected;

  CustomTileData(
      {this.leading,
      this.title,
      this.subtitle,
      this.trailingTopText,
      this.trailingBottomText,
      this.enabled = true,
      this.selected = false});
}

class CustomListTileParameters {
  bool isThreeLine;
  bool dense;
  EdgeInsetsGeometry contentPadding;
  GestureTapCallback onTap;
  GestureLongPressCallback onLongPress;
  FontWeight fontWeight;
  double fontSize;
  String fontFamily;
  Color textColor;
  Color listBgColor;
  Color iconBgColor;
  double circularRadius;
  double listHeight;
  double listWidth;
  double iconHeight;
  double iconWidth;

  CustomListTileParameters(
      {this.isThreeLine = false,
      this.dense,
      this.contentPadding,
      this.onTap,
      this.onLongPress,
      this.textColor,
      this.fontFamily,
      this.fontWeight,
      this.fontSize,
      this.circularRadius,
      this.iconBgColor,
      this.listBgColor,
      this.listHeight,
      this.iconHeight,
      this.iconWidth,
      this.listWidth});
}

class IconButtonParameters {
  Color color;
  IconData icon;
  double iconSize;
  void Function(bool) onPressed;
  Color focusColor;
  Color hoverColor;
  Color splashColor;
  Color highlightColor;
  AlignmentGeometry alignment;

  IconButtonParameters(
      {this.iconSize,
      this.icon,
      this.color,
      this.onPressed,
      this.hoverColor,
      this.focusColor,
      this.splashColor,
      this.highlightColor,
      this.alignment});
}

class FlatButtonParameters {
  IconData icon;
  String buttonText;
  Color color;
  Brightness colorBrightness;
  Color disabledColor;
  double disabledElevation;
  Color disabledTextColor;
  Color focusColor;
  double focusElevation;
  FocusNode focusNode;
  double height;
  Color highlightColor;
  double highlightElevation;
  Color hoverColor;
  double hoverElevation;
  double minWidth;
  @required
  void Function(bool) onPressed;
  void Function(bool) onLongPressed;
  FontWeight fontWeight;
  double fontSize;
  String fontFamily;
  Color textColor;
  ShapeBorder shape;

  FlatButtonParameters(
      {this.onPressed,
        this.onLongPressed,
        this.color,
        this.colorBrightness,
        this.disabledColor,
        this.disabledElevation,
        this.disabledTextColor,
        this.focusColor,
        this.focusElevation,
        this.focusNode,
        this.height,
        this.highlightColor,
        this.highlightElevation,
        this.hoverColor,
        this.hoverElevation,
        this.minWidth,
        this.buttonText,
        this.icon,
        this.fontFamily,
        this.fontWeight,
        this.fontSize,
        this.textColor,this.shape});
}

class FeaturedCardData {
  FeaturedCardData({
    @required this.imgPath,
    bool imgVisibility,
    @required this.title,
    @required this.bodyText,
    @required this.footerText,
    @required this.btnText,
    @required this.firstBtnText,
    @required this.secondBtnText,
    @required this.icon,
    @required this.iconVisibility,
    @required this.imgHeight,
    @required this.imgWidth,
    @required this.containerHeight,
    @required this.containerWidth,
  });

  String imgPath;
  bool imgVisibility;
  String title;
  String bodyText;
  String footerText;
  String btnText;
  String firstBtnText;
  String secondBtnText;
  Widget icon;
  bool iconVisibility;
  double imgHeight;
  double imgWidth;
  double containerHeight;
  double containerWidth;
}

class DropDownParameters {
  String hintText;
  List<String> itemsList;
  Color textColor;
  Color fillColor;
  TextAlign textAlign;
  double width;
  double height;
  double imageWidth;
  double imageHeight;
  String fontFamily;
  FontWeight fontWeight;
  FontStyle fontStyle;
  double fontSize;
  double shadowBlurRadius;
  double shadowSpreadRadius;
  double shadowOffsetX;
  double shadowOffsetY;
  void Function(String) callback;

  DropDownParameters({
    @required this.itemsList,
    this.hintText,
    this.textColor,
    this.height,
    this.width,
    this.fontFamily,
    this.fontStyle,
    this.fontWeight,
    this.fontSize,
    this.callback,
    this.fillColor,
    this.imageWidth,
    this.imageHeight,
    this.textAlign,
    this.shadowBlurRadius,
    this.shadowSpreadRadius,
    this.shadowOffsetX,
    this.shadowOffsetY,
  });
}

class Outlinebuttonparam {
  BorderSide borderSide;
  String buttonText;
  Color color;
  ShapeBorder shape;
  Color textColor;
  IconData icon;
  Color focusColor;
  Color highlightColor;
  Color hoverColor;
  Color splashColor;
  Color borderColor;
  double borderWidth;
  BorderStyle borderStyle;
  @required
  void Function(bool) onPressed;
  void Function(bool) onLongPress;
  FontWeight fontWeight;
  double fontSize;
  String fontFamily;

  Outlinebuttonparam(
      {this.borderSide,
      this.buttonText,
      this.onPressed,
      this.onLongPress,
      this.shape,
      this.textColor,
      this.hoverColor,
      this.highlightColor,
      this.focusColor,
      this.fontSize,
      this.fontWeight,
      this.fontFamily,
      this.icon,
      this.color,
      this.splashColor,
      this.borderColor,
      this.borderStyle,
      this.borderWidth});
}

class DatePicker {
  int startMonth;
  int startYear;
  int endMonth;
  int endYear;
  Color headerColor;
  Color selectColor;
  Color bodybgColor;
  Color dateColor;
  Color dayColor;
  Color monthColor;
  Color buttonText;
  double daySize;
  double monthSize;
  double dateSize;
  FontWeight fontWeight;
  String monthFont;
  String dayFont;
  String dateFont;

  DatePicker(
      {this.startMonth,
        this.startYear,
        this.endMonth,
        this.endYear,
        this.headerColor,
        this.bodybgColor,
        this.dateColor,
        this.dayColor,
        this.monthColor,
        this.selectColor,
        this.buttonText,
        this.fontWeight,
        this.dateSize,
        this.daySize,
        this.monthSize,
        this.dateFont,
        this.dayFont,
        this.monthFont});
}
class Floatingactionbuttonparam {
  Color backgroundColor;
  IconData icon;
  Color foregroundColor;
  bool isExtended;
  ShapeBorder shape;
  void Function(bool) onPressed;
  String buttonText;
  FontWeight fontWeight;
  double fontSize;
  String fontFamily;
  Color hoverColor;
  Color splashColor;

  Floatingactionbuttonparam(
      {this.backgroundColor,
      this.icon,
      this.foregroundColor,
      this.isExtended = false,
      this.onPressed,
      this.shape,
      this.buttonText,
      this.fontWeight,
      this.fontSize,
      this.fontFamily,
      this.hoverColor,
      this.splashColor});
}

class StepperParameters {
  ScrollPhysics physics;
  StepperType type;
  int currentStep;
  ValueChanged<int> onStepTapped;
  VoidCallback onStepContinue;
  VoidCallback onStepCancel;
  ControlsWidgetBuilder controlsBuilder;

  StepperParameters(
      {Key key,
      this.physics,
      this.type = StepperType.vertical,
      this.currentStep,
      this.onStepTapped,
      this.onStepContinue,
      this.onStepCancel,
      this.controlsBuilder});
}

class CustomSteps {
  Widget title;
  Widget subtitle;
  Widget content;
  StepState state;
  bool isActive;

  CustomSteps(
      {this.title, this.subtitle, this.content, this.state, this.isActive});
}

class CustomVerticalTabParameters{
  final Key key;
  final double tabsWidth;
  final double itemExtent;
  final double indicatorWidth;
  final TextDirection direction;
  final Color indicatorColor;
  final bool disabledChangePageFromContentView;
  final Axis contentScrollAxis;
  final Color selectedTabBackgroundColor;
  final Color unselectedTabBackgroundColor;
  final Color dividerColor;
  final Duration changePageDuration;
  final Curve changePageCurve;
  final Color tabsShadowColor;
  final double tabsElevation;

  CustomVerticalTabParameters({
    this.key,
    this.tabsWidth,
    this.itemExtent,
    this.indicatorWidth,
    this.direction = TextDirection.ltr,
    this.indicatorColor ,
    this.disabledChangePageFromContentView,
    this.contentScrollAxis = Axis.vertical,
    this.selectedTabBackgroundColor,
    this.unselectedTabBackgroundColor,
    this.dividerColor,
    this.changePageCurve,
    this.changePageDuration,
    this.tabsShadowColor,
    this.tabsElevation
});
}

