import 'package:flutter/material.dart';
import 'package:flutter_widgets_library/theme/theme.dart';
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'package:flutter_widgets_library/view/widgets/VIC-App/piggybank.dart';
import 'package:flutter_widgets_library/view/widgets/VIC-App/searchPage.dart';
import 'package:flutter_widgets_library/view/widgets/VIC-App/service-history.dart';
import 'package:flutter_widgets_library/view/widgets/VIC-App/services-page-vendor.dart';
import 'package:flutter_widgets_library/view/widgets/VIC-App/vendorWallet.dart';
import 'package:flutter_widgets_library/view/widgets/VIC-App/welcome-page.dart';
import 'package:flutter_widgets_library/view/widgets/custom-Drawer.dart';
import 'package:flutter_widgets_library/view/widgets/custom-appBar.dart';
import 'package:flutter_widgets_library/view/widgets/VIC-App/custom-barGraph.dart';
import 'package:flutter_widgets_library/view/widgets/VIC-App/custom-pieChart.dart';
import 'package:flutter_widgets_library/view/widgets/globals.dart';
import 'package:charts_flutter/flutter.dart' as charts;
import 'package:flutter_widgets_library/view/widgets/VIC-App/services-page.dart';
import 'package:flutter_svg/svg.dart';

import 'Homepage.dart';

//void main() => runApp(MaterialApp(debugShowCheckedModeBanner: false,home: DashboardPageVendor()));

class DashboardPageVendor extends StatefulWidget {
  @override
  _dashboardPageStartup createState() => new _dashboardPageStartup();
}

class _dashboardPageStartup extends State<DashboardPageVendor> {
  static List<ServicesData> pieChartData = [
    new ServicesData('Active', 30, Color(0xffe0301e)),
    new ServicesData('Pending', 10, Color(0xffd93954)),
    new ServicesData('Completed', 40, Color(0xff2d2d2d)),
    new ServicesData('Requested', 20, Color(0xffeb8c00)),
  ];

  static List<charts.Series<ServicesData, String>> pieSeries = [
    new charts.Series<ServicesData, String>(
      id: 'Sales',
      //colorFn: (_, __) => charts.MaterialPalette.lime.shadeDefault,
      domainFn: (ServicesData sales, _) => sales.serviceType,
      measureFn: (ServicesData sales, _) => sales.serviceNumber,
      colorFn: (ServicesData sales, _) =>
          charts.ColorUtil.fromDartColor(sales.mColor),
      labelAccessorFn: (ServicesData row, _) => '${row.serviceNumber}',
      data: pieChartData,
    )
  ];

  static List<GrantsData> barGraphData = [
    new GrantsData('Jan', 5, Color(0xffe0301e)),
    new GrantsData('Feb', 2, Color(0xff2d2d2d)),
    new GrantsData('Mar', 1, Color(0xffd93954)),
    new GrantsData('Apr', 4, Color(0xffeb8c00)),
    new GrantsData('May', 1, Color(0xff464646)),
  ];

  static List<charts.Series<GrantsData, String>> barSeries = [
    new charts.Series<GrantsData, String>(
      id: 'Sales',
      //colorFn: (_, __) => charts.MaterialPalette.lime.shadeDefault,
      domainFn: (GrantsData sales, _) => sales.year,
      measureFn: (GrantsData sales, _) => sales.grants,
      colorFn: (GrantsData sales, _) =>
          charts.ColorUtil.fromDartColor(sales.mColor),
      labelAccessorFn: (GrantsData row, _) => '${row.grants}',
      data: barGraphData,
    )
  ];

  @override
  Widget build(BuildContext context) {
    leftNavRouting(int nIndex, String title) async {
      print(nIndex);
      print(title);
      if (nIndex < 2) {
        tabControllerForCompositeWidget.animateTo(nIndex);
      } else if(nIndex==2) {
        await Future.delayed(Duration(seconds: 1));
        Navigator.push(
          context,
          MaterialPageRoute(builder: (context) => ServiceHistory()),
        );
      }
      else{
        await Future.delayed(Duration(seconds: 1));
        Navigator.push(

          context,
          MaterialPageRoute(builder: (context) => WelcomePage()),
        );

      }
    }

    List<ListItems> drawerList = [
      ListItems(Icons.room_service, "Services"),
      ListItems(Icons.card_travel, "Grants"),
      ListItems(Icons.history, "History"),
      ListItems(Icons.person,"Switch Persona"),
    ];
    CustomLinearProgressBarParameters pb = new CustomLinearProgressBarParameters(value: 0.7,backgroundColor: StartupTheme().secondaryHeaderColor,valueColor: AlwaysStoppedAnimation<Color>(StartupTheme().primaryColorDark,), );

    // These values should come from the global variable now
    User UserObj = new User(
        "images/account_picture.jpg",
        userName,
        designation + ", " + companyname,
        Colors.red,
        FontWeight.bold,
        13,
        null);

    AppBarParameters appBarParams = new AppBarParameters(
        backgroundColor: StartupTheme().splashColor,
        elevation: 5,
        bottomOpacity: 1.0,
        toolbarOpacity: 1.0,
        titleSpacing: 1.0,
        centerTitle: false,
        title: Image.asset('images/logo.jpg', height: 50, width: 50,)
    );
    List<Widget> appBarIcons = [
      IconButton(
        icon:  SvgPicture.asset('images/search.svg',height: 20,width: 20,),
        tooltip: 'Opens the search bar',
        onPressed: () {
          Navigator.push(
              context, MaterialPageRoute(builder: (context) => SearchPage()));
        },
      ),
      IconButton(
        icon:  SvgPicture.asset('images/graphs.svg',height: 20,width: 20,),
        tooltip: 'Opens Graphs',
        onPressed: () {
          Navigator.push(
            context,
            MaterialPageRoute(builder: (context) => DashboardPageVendor()),
          );
        },
      ),
      IconButton(
        icon:  SvgPicture.asset('images/wallet.svg',height: 20,width: 20,),
        tooltip: 'Opens Wallet',
        onPressed: () {
          showDialog(
              context: context,
              builder: (context) =>
                  VendorWaller());
        },
      ),
      IconButton(
        icon:  SvgPicture.asset('images/services.svg',height: 20,width: 20,),
        tooltip: 'Opens Services',
        onPressed: () {
          Navigator.push(
            context,
            MaterialPageRoute(builder: (context) => ServiceVendor()),
          );
        },
      ),

    ];

    ChartsPie objPieOne = new ChartsPie(pieSeries, 50);
    ChartsBar objBarOne = new ChartsBar(barSeries);

    return MaterialApp(
      debugShowCheckedModeBanner: false,
      theme: StartupTheme(),
      title: "Vendor Dashboard",
      home: Scaffold(
          drawer: CustomDrawer(drawerList, leftNavRouting, UserObj,pb),
          appBar: CustomAppBar(appBarIcons, appBarParams),
          body: SingleChildScrollView(
            child: Container(
              margin: EdgeInsets.only(top: 20),
              child: Column(
                mainAxisAlignment: MainAxisAlignment.start,
                mainAxisSize: MainAxisSize.max,
                children: <Widget>[
                  Container(
                      height: 300,
                      padding: EdgeInsets.all(15),
                      child: Card(
                          borderOnForeground: true,
                          elevation: 15,
//                        shadowColor: StartupTheme().secondaryHeaderColor,
                          child: Padding(
                            padding: const EdgeInsets.all(8),
                            child: Column(
                              children: <Widget>[
                                Text("Engagements by type",
                                    style: TextStyle(
                                        color: StartupTheme().hintColor,
                                        fontWeight: FontWeight.bold)),
                                Expanded(flex: 50, child: objPieOne),
                              ],
                            ),
                          ))),
                  Container(
                      height: 300,
                      padding: EdgeInsets.all(15),
                      child: Card(
                          elevation: 15,
//                        shadowColor: StartupTheme().secondaryHeaderColor,
                          child: Padding(
                            padding: const EdgeInsets.all(8),
                            child: Column(
                              children: <Widget>[
                                Text("Income received per month",
                                    style: TextStyle(
                                        color: StartupTheme().hintColor,
                                        fontWeight: FontWeight.bold)),
                                Expanded(flex: 50, child: objBarOne)
                              ],
                            ),
                          )))
                ],
              ),
            ),
          ),
          ),
    );
  }
}

class ServicesData {
  final String serviceType;
  final int serviceNumber;
  final Color mColor;
  ServicesData(this.serviceType, this.serviceNumber, this.mColor);
}

class GrantsData {
  final String year;
  final int grants;
  final Color mColor;

  GrantsData(this.year, this.grants, this.mColor);
}