import 'dart:ui';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_widgets_library/theme/color.dart';
import 'package:flutter_widgets_library/theme/theme.dart';
import 'package:flutter_widgets_library/utils/consts.dart';
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'package:flutter_widgets_library/view/widgets/VIC-App/thumb-auth.dart';
import 'package:flutter_widgets_library/view/widgets/VIC-App/vic-signup.dart';
import 'package:flutter_widgets_library/view/widgets/custom-switch.dart';
import 'package:flutter_widgets_library/view/widgets/globals.dart' as vPersona;


class Login extends StatefulWidget {
  @override
  State<StatefulWidget> createState() {
    return _LoginPage();
  }
}

class _LoginPage extends State<Login> {
  final TextEditingController _usernameController = TextEditingController();
  final TextEditingController _passwordController = TextEditingController();
  String error = "";
  bool validate = true;
  String userType = '';

  void displayDialog(context, title, text) => showDialog(
        context: context,
        builder: (context) =>
            AlertDialog(title: Text(title), content: Text(text)),
      );

  @override
  Widget build(BuildContext context) {
    onDropdownSelect(String value) {
      userType = value;
    }

    final DropDownParameters dropdown = new DropDownParameters(
        hintText: 'Select User Type',
        width: 180,
        height: 30,
        textColor: LiteThemeData().primaryColorDark,
        fillColor: LiteThemeData().backgroundColor,
        itemsList: ['startup', 'vendor'],
        callback: onDropdownSelect);

    return MaterialApp(debugShowCheckedModeBanner: false,
        theme: StartupTheme(),
        title: "Login Page",
        home: Scaffold(
          body: SingleChildScrollView(
            padding: const EdgeInsets.all(35.0),
            child: Column(
              children: <Widget>[
                SizedBox(
                  height: 80,
                ),
                Text(
                  "Log In",
                  style: TextStyle(fontSize: 30, fontFamily: 'Roboto'),
                  textAlign: TextAlign.center,
                  overflow: TextOverflow.visible,
                ),
                SizedBox(
                  height: 50,
                ),
                Row(
                  children: <Widget>[
                    Text('This login has two step authentication',
                        style: TextStyle(fontFamily: 'Roboto', fontSize: 16)),
                    SizedBox(
                      height: 30,
                    )
                  ],
                ),
                SizedBox(
                  height: 20,
                ),
                TextField(
                  controller: _usernameController,
                  decoration: InputDecoration(
                    border: new OutlineInputBorder(
                      borderRadius: const BorderRadius.all(
                        const Radius.circular(50.0),
                      ),
                    ),
                    prefixIcon: Icon(
                      Icons.person_outline,
                    ),
                    labelText: 'Username',
                    labelStyle: TextStyle(fontSize: fontMedium),
                    errorText: validate ? error : null,
                  ),
                ),
                SizedBox(
                  height: 10,
                ),
                TextField(
                  controller: _passwordController,
                  obscureText: true,
                  decoration: InputDecoration(
                    border: new OutlineInputBorder(
                      borderRadius: const BorderRadius.all(
                        const Radius.circular(50.0),
                      ),
                    ),
                    prefixIcon: Icon(
                      Icons.lock,
                    ),
                    labelText: 'Password',
                    labelStyle: TextStyle(fontSize: fontMedium),
                    errorText: validate ? error : null,
                  ),
                ),
                SizedBox(
                  height: 60,
                ),
                SizedBox(
                  child: FlatButton(
                    shape: RoundedRectangleBorder(
                        borderRadius: new BorderRadius.circular(heightFifty)),
                    color: StartupTheme().splashColor,
                    padding: EdgeInsets.fromLTRB(100, 10, 100, 10),
                    onPressed: () async {
                      var username = _usernameController.text;
                      userType = vPersona.userName;
                      vPersona.userName = username;
                      Navigator.push(context,
                          MaterialPageRoute(builder: (context) => ThumbAuth()));
                    },
                    child: Text(
                      "LOG IN",
                      style: TextStyle(
                          fontSize: fontMedium,
                          color: StartupTheme().accentColor),
                    ),
                  ),
                  width: heightThreeHundred,
                  height: 50,
                ),
                SizedBox(
                  height: 20,
                ),
                SizedBox(
                  child: OutlineButton(
                    borderSide: BorderSide(color: StartupTheme().splashColor),
                    shape: RoundedRectangleBorder(
                      borderRadius: new BorderRadius.circular(heightFifty),
                    ),
                    color: StartupTheme().accentColor,
                    padding: EdgeInsets.fromLTRB(100, 10, 100, 10),
                    onPressed: () async {
                      Navigator.push(context,
                          MaterialPageRoute(builder: (context) => SignUp()));
                    },
                    child: Text(
                      "SIGN UP",
                      style: TextStyle(
                          fontSize: fontMedium,
                          color: StartupTheme().primaryColorDark),
                    ),
                  ),
                  width: heightThreeHundred,
                  height: 50,
                )
              ],
            ),
          ),
        ));
  }
}
