/*
Description:
Composite card widget that follows a two column structure. The first column typically houses data using a Title and a Subtitle.
THe second column can intake a single widget or an array of widgets (Switch, Text Box, Check box, Radio Button).

Usage:
The user has to pass in the division of the two columns using the flex values for the two columns.
The title and the subtitle variables can intake String values while the rightHandWidgets variable can take an array of Widgets.
This array of widgets can be a single widget like an individual widget or a Container or multiple widgets in an array format.
Optional parameters like margin, shadowColor textSpacing etc can be used to modify the look and feel of each card.

   List<CustomCompositeCardParameters> listcards = [];
    CustomCompositeCardParameters card1 = new CustomCompositeCardParameters(
        flexColumn1: 3,
        flexColumn2: 5,
        title: "Sample Title",
        subtitle: "Sample Subtitle",
        rightHandWidgets: [
          Text("Enter your hobby"),
          Checkbox(value: cons.MAX_Length_Enforced, activeColor: Colors.red),
          TextField()
        ],
        leftHandWidgets: [
          Text("Enter your gender"),
          Row(children: [
            Radio(
              value: "female",
              groupValue: "gender",
              activeColor: Colors.green,
              onChanged: onRadioChanged,
              autofocus: true,
            ),
            Text("Female")
          ]),
          Row(children: [
            Radio(
                value: "male",
                groupValue: "gender",
                activeColor: Colors.red,
                onChanged: onRadioChanged),
            Text("Male")
          ])
        ]);
    CustomCompositeCardParameters card2 = new CustomCompositeCardParameters(
        flexColumn1: 3,
        flexColumn2: 5,
        title: "Sample Title",
        subtitle: "Sample Subtitle",
        rightHandWidgets: [
          Text("Enter")
        ],
        leftHandWidgets: [

          Row(children: [
            Radio(
              value: "female",
              groupValue: "gender",
              activeColor: Colors.green,
              onChanged: onRadioChanged,
              autofocus: true,
            ),
            Text("Female")
          ]),
          Row(children: [
            Radio(
                value: "male",
                groupValue: "gender",
                activeColor: Colors.red,
                onChanged: onRadioChanged),
            Text("Male")
          ])
        ]);

    listcards.add(card1);
    listcards.add(card2);


Author:
Rishabh Thakur,Ishita Agrawal

*/

import 'package:flutter/material.dart';
import 'package:flutter_widgets_library/theme/theme.dart';
import 'package:flutter_widgets_library/utils/consts.dart' as cons;
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';

Widget CompositeCard(List<CustomCompositeCardParameters> cardList) {
  List<Card> cards = [];
  var card;
  var cardvar;
  if (cardList == null) {
    return Card(
      color: MediumGreyThemeData().iconTheme.color,
      child: Row(
        children: <Widget>[
          Expanded(
            flex: cons.DIVS,
            child: Checkbox(
                value: cons.MAX_Length_Enforced, activeColor: Colors.red),
          ),
          Spacer(),
          Expanded(
            flex: cons.DIVS,
            child: Checkbox(
                value: cons.MAX_Length_Enforced, activeColor: Colors.red),
          )
        ],
      ),
    );
  } else {
    for (cardvar = 0; cardvar < cardList.length; cardvar++) {
      card = new Card(
        margin: (cardList[cardvar].margin != null)
            ? EdgeInsets.all(cardList[cardvar].margin)
            : EdgeInsets.all(cons.heightTen),
        elevation: (cardList[cardvar].elevation != null)
            ? cardList[cardvar].elevation
            : cons.heightFive,
        color: (cardList[cardvar].cardColor != null)
            ? cardList[cardvar].cardColor
            : MediumGreyThemeData().accentIconTheme.color,
        child: Row(
          children: <Widget>[
            Expanded(
              flex: (cardList[cardvar].flexColumn2 != null)
                  ? cardList[cardvar].flexColumn2
                  : cons.DIVS,
              child: (cardList[cardvar].leftHandWidgets != null)
                  ? Column(
                      mainAxisSize: MainAxisSize.min,
                      children: cardList[cardvar].leftHandWidgets)
                  : Checkbox(
                      value: cons.MAX_Length_Enforced, activeColor: Colors.red),
            ),
            Spacer(),
            Expanded(
              flex: (cardList[cardvar].flexColumn2 != null)
                  ? cardList[cardvar].flexColumn2
                  : cons.DIVS,
              child: (cardList[cardvar].rightHandWidgets != null)
                  ? Center(child : Column(
                      mainAxisSize: MainAxisSize.min,
                      children: cardList[cardvar].rightHandWidgets))
                  : Checkbox(
                      value: cons.MAX_Length_Enforced, activeColor: Colors.red),
            )
          ],
        ),
      );
      cards.add(card);
    }
    return Column(
      children: cards,
      mainAxisSize: cons.mainAxis_size,
    );
  }
}