/*
Description:
A widget that creates a layout consisting of an AppBar, Left Navigation Bar and a Tab Bar alongside views for each tab bar.
The widget intakes the following values and properties for each of its 3 components.
1. Parameter for creating an App Bar
2. Icons to be displayed on the App Bar
3. Tabs to be displayed in the Tab Bar
4. User Info to be shows in the Left Nav Bar
5. Items to be displayed in the Left Nav Bar
6. Callback functions for Left Nav Bar and other widgets.

Usage:
The user will initialize and define variables for each of the Widget Parameters.
The widget can be called in the following manner:

    AppBarWithTabsAndDrawer(appBarParameters, appBarIconsList, tabBarItems, userObjectInfo, leftNavBarItems, callbackForIcons, leftNavRouting)));

Author:
Rishabh Thakur
*/

import 'package:flutter/material.dart';
import 'package:flutter_widgets_library/theme/theme.dart';
import 'package:flutter_widgets_library/theme/color.dart';
import 'package:flutter_widgets_library/utils/consts.dart' as cons;
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'package:flutter_widgets_library/view/widgets/custom-appBar.dart';
import 'package:flutter_widgets_library/view/widgets/globals.dart';
import '../custom-Drawer.dart';

class AppBarWithTabsAndDrawer extends StatefulWidget {
  AppBarParameters appBarParams;
  List<Widget> appBarIcons;
  List<TabBarProducts> tabsInfo;
  User userInfo;
  List<ListItems> listItems;
  Function(int, String) navBarCallback;
  Function(int, String) leftNavRouting;
  CustomLinearProgressBarParameters customLinearProgressBarParameters;
  AppBarWithTabsAndDrawer(
      this.appBarParams,
      this.appBarIcons,
      this.tabsInfo,
      this.userInfo,
      this.listItems,
      this.navBarCallback,
      this.leftNavRouting,this.customLinearProgressBarParameters);

  @override
  State<StatefulWidget> createState() {
    return _testClass(
        this.appBarParams,
        this.appBarIcons,
        this.tabsInfo,
        this.userInfo,
        this.listItems,
        this.navBarCallback,
        this.leftNavRouting,this.customLinearProgressBarParameters);
  }
}

class _testClass extends State<AppBarWithTabsAndDrawer>
    with SingleTickerProviderStateMixin {
  AppBarParameters appBarParams;
  List<Widget> appBarIcons;
  List<TabBarProducts> tabsInfo;
  User userInfo;
  List<ListItems> listItems;
  Function(int, String) navBarCallback;
  Function(int, String) leftNavRouting;
  CustomLinearProgressBarParameters customLinearProgressBarParameters;

  _testClass(this.appBarParams, this.appBarIcons, this.tabsInfo, this.userInfo,
      this.listItems, this.navBarCallback, this.leftNavRouting,this.customLinearProgressBarParameters);

  @override
  void initState() {
    super.initState();
    tabControllerForCompositeWidget =
        TabController(initialIndex: 0, vsync: this, length: tabsInfo.length);
  }

  @override
  void dispose() {
    tabControllerForCompositeWidget.dispose();
    super.dispose();
  }
  @override
  Widget build(BuildContext context) {
    print(tabsInfo);
    List<Tab> tabList = [];
    List<Widget> tabWidgets = [];
    var tab;
    for (var i = 0; i < tabsInfo.length; i++) {
      tab = new Tab(
          text: tabsInfo[i].text,
          icon: Icon(tabsInfo[i].icons) != null
              ? Icon(tabsInfo[i].icons)
              : Icon(Icons.favorite));
      tabList.add(tab);
    }
    for (var i = 0; i < tabsInfo.length; i++) {
      tab = tabsInfo[i].widget;
      tabWidgets.add(tab);
    }
    // If the user doesn't pass a Tab Bar as part of parameters
    if (appBarParams.bottom == null) {
      appBarParams.bottom = TabBar(
        controller: tabControllerForCompositeWidget,
        labelColor: AppColorsMediumGrey.white,
        indicatorColor: AppColorsMediumGrey.black,
        unselectedLabelColor: AppColorsMediumGrey.yellow,
        indicator: BoxDecoration(
          boxShadow: [
            BoxShadow(
                color: AppColorsYellow.tdColor, offset: cons.offsetDefault)
          ],
          color: AppColorsYellow.tColor,
        ),
        tabs: tabList,
      );
    }

    return Scaffold(
      drawer: CustomDrawer(listItems, leftNavRouting, userInfo,customLinearProgressBarParameters),
      backgroundColor: MediumGreyThemeData().scaffoldBackgroundColor,
      appBar: CustomAppBar(appBarIcons, appBarParams),
      body: new TabBarView(
        children: tabWidgets,
        controller: tabControllerForCompositeWidget,
      ),
    );
  }
}
