/*
Description:
A widget that combines the search functionality with the App bar.
On clicking the search button in the App Bar, A text field appears below the App Bar.
The result of the search field (text box) are returned back to the user who can then map it accordingly.
The sample implementations showcases stubbed ListTiles as search results.

Usage:
The user will initialize and define variables for the following:
1. Creating an App Bar by defining its properties like shape, icon, text etc.
2. List of icons to be displayed in the App Bar
3. Properties for the search text field like maximum length, obscure text etc.
4. Callback function for List Tiles and text field
5. Properties for search text field
6. Widget Parameters for text Field

    CustomSearchBar(appBarParameters, listTileParameters, listofAppBarIcons, cakkback, textFieldData, textFieldParameters)

Author:
Rishabh Thakur
*/

import 'package:flutter/material.dart';
import 'package:flutter_widgets_library/utils/consts.dart' as cons;
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'package:flutter_widgets_library/view/widgets/custom-Drawer.dart';
import 'package:flutter_widgets_library/view/widgets/custom-appbar.dart';
import 'package:flutter_widgets_library/view/widgets/custom-listTileWithImage.dart';
import 'package:flutter_widgets_library/view/widgets/custom-textField.dart';

class CustomSearchBar extends StatefulWidget {
  AppBarParameters appBarParams;
  CustomListTileParameters listTileParams;
  List<Widget> appBarIcons;
  Function(int, String) callback;
  TextFieldContents textFieldData;
  TextFieldParameters textFieldParams;
  List<ListItems> drawerList;
  CustomLinearProgressBarParameters customLinearProgressBarParameters;
  User UserObj;
  Function(int, String) leftNavBarCallback;
  CustomSearchBar(
      this.appBarParams,
      this.listTileParams,
      this.appBarIcons,
      this.callback,
      this.textFieldData,
      this.textFieldParams,
      this.drawerList,
      this.UserObj,
      this.leftNavBarCallback,this.customLinearProgressBarParameters);
  @override
  State<StatefulWidget> createState() {
    return _customSearchBar(
        this.appBarParams,
        this.listTileParams,
        this.appBarIcons,
        this.callback,
        this.textFieldData,
        this.textFieldParams,
        this.drawerList,
        this.UserObj,
        this.leftNavBarCallback,this.customLinearProgressBarParameters);
  }
}

class _customSearchBar extends State<CustomSearchBar> {
  AppBarParameters appBarParams;
  CustomListTileParameters listTileParams;
  List<Widget> appBarIcons;
  Function(int, String) callback;
  TextFieldContents textFieldData;
  TextFieldParameters textFieldParams;
  List<ListItems> drawerList;
  CustomLinearProgressBarParameters customLinearProgressBarParameters;
  User UserObj;
  Function(int, String) leftNavBarCallback;
  _customSearchBar(
      this.appBarParams,
      this.listTileParams,
      this.appBarIcons,
      this.callback,
      this.textFieldData,
      this.textFieldParams,
      this.drawerList,
      this.UserObj,
      this.leftNavBarCallback,this.customLinearProgressBarParameters);
  List<CustomTileData> tileData = [];
  @override
  Widget build(BuildContext context) {
    onTextSubmit(String sText) {
      setState(() {
        tileData = [];
        CustomTileData searchItem1 = new CustomTileData(
            leading: Icon(cons.icon1),
            title: sText,
            subtitle: cons.cardSubtitle,
            trailingTopText: cons.listTop,
            trailingBottomText: cons.listBottom);
        tileData.add(searchItem1);
      });
    }

    return Scaffold(
      drawer: CustomDrawer(drawerList, leftNavBarCallback, UserObj,customLinearProgressBarParameters),
      appBar: CustomAppBar(appBarIcons, appBarParams),
      body: SingleChildScrollView(
        child: Column(
          children: <Widget>[
            CustomTextField(
                data: textFieldData,
                params: textFieldParams,
                callbackTextfield: onTextSubmit),
            //CustomListTile(tileData, listTileParams, callback)
          ],
        ),
      ),
    );
  }
}
