import 'package:flutter/material.dart';
import 'package:flutter_widgets_library/utils/consts.dart' as consts;
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'package:quiver/iterables.dart';
import 'package:flutter_widgets_library/theme/theme.dart';



CustomDatePicker(DatePicker param, BuildContext context,
    void Function(DateTime) onSelect) async {
  if (param == null) {
    DateTime date = await showDatePicker(
      context: context,
      firstDate: DateTime(consts.start_year, consts.start_month, consts.one,
          consts.zero, consts.zero, consts.zero),
      lastDate: DateTime(consts.end_year, consts.end_month, consts.one,
          consts.zero, consts.zero, consts.zero),
      initialDate: DateTime.now(),
      builder: (BuildContext context, Widget child) {
        return Theme(
            data: Theme.of(context).copyWith(
              primaryColor: MediumGreyThemeData().primaryColor,
              accentColor: MediumGreyThemeData().accentColor,
              colorScheme: ColorScheme.light(
                primary: MediumGreyThemeData().buttonColor,
              ),
              dialogBackgroundColor: MediumGreyThemeData().backgroundColor,
              textTheme: TextTheme(
                subhead:
                TextStyle(color: MediumGreyThemeData().accentIconTheme.color),
                body1:
                TextStyle(color: MediumGreyThemeData().accentIconTheme.color),
                caption:
                TextStyle(color: MediumGreyThemeData().accentIconTheme.color),
              ),
              buttonTheme: ButtonThemeData(textTheme: ButtonTextTheme.primary),
            ));

        //dialogBackgroundColor: Colors.white,//Background color
      },
    );

    if (date != null) {
      onSelect(date);
    }
  } else {
    DateTime date = await showDatePicker(
      context: context,
      firstDate: DateTime(
          param.startYear != null ? param.startYear : consts.start_year,
          param.startMonth != null ? param.startMonth : consts.start_month,
          consts.one,
          consts.zero,
          consts.zero,
          consts.zero),
      lastDate: DateTime(
          param.endYear != null ? param.endYear : consts.end_year,
          param.endMonth != null ? param.endMonth : consts.end_month,
          consts.one,
          consts.zero,
          consts.zero,
          consts.zero),
      initialDate: DateTime.now(),
      builder: (BuildContext context, Widget child) {
        return Theme(
          data: Theme.of(context).copyWith(
            primaryColor: (param.headerColor != null)
                ? param.headerColor
                : MediumGreyThemeData().primaryColor,
            accentColor: (param.selectColor != null)
                ? param.selectColor
                : MediumGreyThemeData().accentColor,
            colorScheme: ColorScheme.light(
              primary: (param.buttonText != null)
                  ? param.buttonText
                  : MediumGreyThemeData().buttonColor,
            ),
            dialogBackgroundColor: (param.bodybgColor != null)
                ? param.bodybgColor
                : MediumGreyThemeData().backgroundColor,
            textTheme: TextTheme(
              subhead: TextStyle(
                  color: (param.monthColor != null)
                      ? param.monthColor
                      : MediumGreyThemeData().accentIconTheme.color,
                  fontWeight: (param.fontWeight != null)
                      ? param.fontWeight
                      : consts.fontBold,
                  fontSize: param.monthSize != null
                      ? param.monthSize
                      : consts.font_medium,
                  fontFamily: param.monthFont != null
                      ? param.monthFont
                      : MediumGreyThemeData().textTheme.caption.fontFamily),
              body1: TextStyle(
                  color: (param.dateColor != null)
                      ? param.dateColor
                      : MediumGreyThemeData().accentIconTheme.color,
                  fontWeight: (param.fontWeight != null)
                      ? param.fontWeight
                      : consts.fontBold,
                  fontSize: param.dateSize != null
                      ? param.dateSize
                      : consts.font_medium,
                  fontFamily: param.dateFont != null
                      ? param.dateFont
                      : MediumGreyThemeData().textTheme.caption.fontFamily),
              caption: TextStyle(
                  color: (param.dayColor != null)
                      ? param.dayColor
                      : MediumGreyThemeData().accentIconTheme.color,
                  fontWeight: (param.fontWeight != null)
                      ? param.fontWeight
                      : consts.fontBold,
                  fontSize: param.daySize != null
                      ? param.daySize
                      : consts.font_medium,
                  fontFamily: param.dayFont != null
                      ? param.dayFont
                      : MediumGreyThemeData().textTheme.caption.fontFamily),
            ),
            buttonTheme: ButtonThemeData(
              textTheme: ButtonTextTheme.primary,
            ),


          ),
          child: child,
        );
      },
    );
    if (date != null) {
      onSelect(date);
    }
  }
}