import 'package:flutter/material.dart';
import 'package:flutter_widgets_library/theme/theme.dart';
import 'package:flutter_widgets_library/utils/consts.dart';
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'package:flutter_widgets_library/utils/consts.dart' as con;

class CustomDropdownButton extends StatefulWidget {
  final DropDownParameters param;

  CustomDropdownButton({
    Key key,
    @required this.param,
  }) : super(key: key);

  @override
  _CustomDropdownButton createState() => _CustomDropdownButton();
}

class _CustomDropdownButton extends State<CustomDropdownButton> {
  final DropDownParameters param;

  _CustomDropdownButton({Key key, this.param});

  String dropdownValue;

  Widget build(BuildContext context) {
    return Padding(
      padding: con.edgeInsetValues,
      child: Container(
        height: ((widget.param.height) != null)
            ? widget.param.height
            : con.heightSixty,
        width: ((widget.param.width) != null)
            ? widget.param.width
            : con.dropDown_width,
        decoration: BoxDecoration(
            border: Border.all(color: LiteThemeData().primaryColorDark),
            borderRadius:
                BorderRadius.circular(con.heightFifty),
            color: (widget.param.fillColor != null)
                ? widget.param.fillColor
                : Colors.red,
            boxShadow: [
              BoxShadow(
                  color: MediumGreyThemeData().scaffoldBackgroundColor,
                  offset: Offset(
                      (widget.param.shadowOffsetX == null)
                          ? con.shadow_offsetx
                          : widget.param.shadowOffsetX,
                      (widget.param.shadowOffsetY == null)
                          ? con.shadow_offsety
                          : widget.param.shadowOffsetY),
                  blurRadius: (widget.param.shadowBlurRadius == null)
                      ? con.blur_radius
                      : widget.param.shadowBlurRadius,
                  spreadRadius: (widget.param.shadowSpreadRadius == null)
                      ? con.spread_radius
                      : widget.param.shadowSpreadRadius)
            ]),
        child: Theme(
            data: Theme.of(context).copyWith(
                canvasColor: Colors.white,
                // background color for the dropdown items
                buttonTheme: ButtonTheme.of(context).copyWith(
                  alignedDropdown:
                      true,
                )),
            child: DropdownButtonHideUnderline(
              child: DropdownButton<String>(
                isExpanded: true,
                iconEnabledColor: MediumGreyThemeData().scaffoldBackgroundColor,
                items: widget.param.itemsList.map((String value) {
                  return DropdownMenuItem<String>(
                    value: value,
                    child: (!(Uri.parse(value).isAbsolute &&
                            (value.contains(con.jpg) ||
                                value.contains(con.png) ||
                                value.contains(con.jpeg))))
                        ? Text(
                            value,
                            style: TextStyle(
                                fontSize: (widget.param.fontSize != null)
                                    ? widget.param.fontSize
                                    : con.font_medium,
                                color: widget.param.textColor,
                                fontWeight: widget.param.fontWeight),
                          )
                        : Image.network(
                            value,
                            height: (widget.param.imageHeight == null)
                                ? con.heightSixty
                                : widget.param.imageHeight,
                            width: (widget.param.imageWidth == null)
                                ? con.image_width
                                : widget.param.imageWidth,
                          ),
                  );
                }).toList(),
                hint: Text(
                  widget.param.hintText,
                  textAlign: (widget.param.textAlign == null)
                      ? TextAlign.left
                      : widget.param.textAlign,
                  style: TextStyle(
                      fontSize: (widget.param.fontSize != null)
                          ? widget.param.fontSize
                          : con.font_medium,
                      color: widget.param.textColor,
                      fontWeight: widget.param.fontWeight),
                ),
                // setting hint
                onChanged: (String value) {
                  setState(() {
                    dropdownValue = value;
                    widget.param.callback(dropdownValue);
                  });
                },

                value: dropdownValue,
              ),
            )),
      ),
    );
  }
}
