/*
Description:
A widget that dynamically creates a list of menu items for quick interactions that do not require a full screen to do.
The widget accepts Icons and Text, it populates a list of these clickable Icons and its corresponding Text.


Usage:
The user can pass in a list of IconButtons and texts.
The user can also pass on parameters like shadow elevation, border decoration etc.
See BottomSheetContents and BottomSheetParameters class definitons for more information.
The user also passes a callback function which is invoked when an icon is Tapped.
- The widget returns the index value and the title of that particular tile.

     List<BottomSheetContents> contents = [];
     BottomSheetContents contObj1 = new BottomSheetContents(
        IconButton(...),"Share");
     contents.add(contObj1);
     BottomSheetParameters params = new BottomSheetParameters(elevation: 50.0, shape: ..., backgroundColor: ...);
    customBottomSheet(contents, params, Callback)

Author:
Anubhav Sinha
*/


import 'package:flutter/material.dart';
import 'package:flutter_widgets_library/theme/theme.dart';
import 'package:flutter_widgets_library/utils/consts.dart' as cons;
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';

Widget customBottomSheet (List<BottomSheetContents> contents, BottomSheetParameters params, Function(int,String)callbackBottomSheet){
  if (contents != null && contents.length != 0){
    return Scaffold(
      body: Builder(
        builder:  (context) => Align (
            alignment: Alignment.bottomRight,
            child: FloatingActionButton(
              onPressed: () {
                showBottomSheet(context: context, elevation:(params.elevation != null)? params.elevation: cons.heightFive , shape: params.shape, backgroundColor: (params.backgroundColor != null)? params.backgroundColor: params.backgroundColor, builder: (context) => ConstrainedBox(
                  constraints: new BoxConstraints(
                    minHeight: cons.MIN_HEIGHT,
                    maxHeight: cons.MAX_HEIGHT,
                  ),
                  child: Container(
                    margin: EdgeInsets.symmetric(horizontal:cons.padding_value1, vertical: cons.padding_value2 ),
                    //color: PwCMediumGreyThemeData().primaryColor,
                    child: ListView.builder(
                        itemCount: contents.length,
                        itemBuilder: (context, index){
                          return Row(
                            children: <Widget>[
                              Container(

                                  child: IconButton(
                                    icon: contents[index].IconB,
                                    iconSize: cons.icon_size1,
                                    onPressed: (){
                                      return callbackBottomSheet(index, contents[index].Text1);
                                    },
                                    color: MediumGreyThemeData()
                                        .buttonColor,)
                              ),
                              Container(

                                  padding: EdgeInsets.all(5),
                                  child: Text('${contents[index].Text1}',
                                      style: TextStyle(fontSize: cons.font_size1,
                                          fontWeight: FontWeight.w900,
                                          color: MediumGreyThemeData()
                                              .cursorColor)
                                  )
                              )
                            ],
                          );
                        }
                    ),
                  ),
                ));
              },
            )
        ),
      ),
    );
  }//if

  else{
    //default
    return Scaffold(
      body: Builder(
        builder:  (context) => Align (
            alignment: Alignment.bottomRight,
            child: FloatingActionButton(
              onPressed: () {
                showBottomSheet(context: context, builder: (context) => ConstrainedBox(
                  constraints: new BoxConstraints(
                    minHeight: cons.MIN_HEIGHT,
                    maxHeight: cons.MAX_HEIGHT,
                  ),
                  child: Container(
                    margin: EdgeInsets.symmetric(horizontal:cons.padding_value1, vertical: cons.padding_value2 ),
                    //color: PwCMediumGreyThemeData().primaryColor,
                    child: ListView.builder(
                        itemCount: 1,
                        itemBuilder: (context, index){
                          return Row(
                            children: <Widget>[
                              Container(
                                //flex: 1,
                                  child: IconButton(
                                    icon: Icon(cons.icon1),
                                    iconSize: cons.icon_size1,
                                    color: MediumGreyThemeData()
                                        .buttonColor,)
                              ),
                              Container(
                                //flex: 2,
                                  padding: EdgeInsets.all(5),
                                  child: Text(cons.dialogButtonText,
                                      style: TextStyle(fontSize: cons.font_size1,
                                          fontWeight: FontWeight.w900,
                                          color: MediumGreyThemeData()
                                              .cursorColor)
                                  )
                              )
                            ],
                          );
                        }
                    ),
                  ),
                ));
              },
            )
        ),
      ),
    );
  }

}




