import 'package:flutter/material.dart';
import 'package:flutter_widgets_library/theme/theme.dart';

/*This widget is used to display a Data Table.
    The view comprises datarows, datacolumns, which in turn comprise of datacells.
    This is a stateless widget.
    The user specifies the headers in the data column, and the data in the datarows.

    SAMPLE IMPLEMENTATION:
    Row row1=new Row(["Ganguly", "38", "Cricketer"]);
    Row row2=new Row(["Messi", "32", "Footballer"]);
    List<Row> rows=[];
    rows.add(row1);
    rows.add(row2);
    Columns column = new Columns(["name", "age", "Work"]);
    DataTableSchema dt=new DataTableSchema(column, 1, true, rows );

    //implementation
    Center(
                  child: CustomisedDataTable(dt)
              )

    */

//AUTHOR : Soumyadeep Mitra

//WIDGET FOR DATA TABLE
Widget CustomisedDataTable(DataTableSchema dataTable) {
  List<DataRow> r = [];
  List<DataCell> dc = [];
  List<DataColumn> c = [];

  for (var value in dataTable.columns.columnHeaders)
    c.add(DataColumn(
      label: Text(
        value,
        style: TextStyle(fontStyle: FontStyle.italic,color: StartupTheme().hintColor),
      ),
    ));

  for (var value in dataTable.rows) {
    dc = [];
    for (var value1 in value.row) {
      dc.add(DataCell(Text(value1,style: TextStyle(fontStyle: FontStyle.italic,color: StartupTheme().hintColor),)));
    }
    r.add(DataRow(cells: dc));
  }

  return Container(

    color: StartupTheme().accentColor,
    child: DataTable(
      columns: c,
      rows: r,
      sortAscending: dataTable.sortAscending,
      sortColumnIndex: dataTable.sortColumnIndex,

    ),
  );
}

//Model for the DataTable
class DataTableSchema {
  Columns columns;
  int sortColumnIndex;
  bool sortAscending;
  List<Rows> rows;

  DataTableSchema(
      this.columns, this.sortColumnIndex, this.sortAscending, this.rows);
}

//Model for Columns
class Columns {
  List<String> columnHeaders;
  Columns(this.columnHeaders);
}

//Model for rows
class Rows {
  List<String> row;
  Rows(this.row);
}
