/*
Description:
A divider tool that creates a horizontal lined divison or seperation.
Can be used to seperate list elements in a List View or create divisions on a page.

Usage:
The user can pass in parameters to the widget like line color, thickness, spacing margins etc.
See CustomDividerParameters for more information.

    CustomDividerParameters dividerParameters = new CustomDividerParameters(height: 1, thickness: 2, indent: 1, endIndent: 1, color: Colors.red);
    CustomDivider(dividerParameters);

Author:
Rishabh Thakur
*/

import 'package:flutter/material.dart';
import 'package:flutter_widgets_library/theme/theme.dart';
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'package:flutter_widgets_library/utils/consts.dart' as cons;

Widget CustomDivider(CustomDividerParameters dividerParams) {
  // Incase user doesn't pass any parameters
  if (dividerParams == null) {
    return Divider(
      height: cons.heightTwentyPixel,
      thickness: cons.thicknesssTwoPixel,
      indent: cons.indentOnePixel,
      endIndent: cons.endIndentOnePixel,
      color: MediumGreyThemeData().highlightColor,
    );
  } else {
    // Incase user passes all or limited number of parameters
    return Divider(
      height: (dividerParams.height == null)
          ? cons.heightTwentyPixel
          : dividerParams.height,
      thickness: (dividerParams.thickness == null)
          ? cons.thicknesssTwoPixel
          : dividerParams.thickness,
      indent: (dividerParams.indent == null)
          ? cons.indentOnePixel
          : dividerParams.indent,
      endIndent: (dividerParams.endIndent == null)
          ? cons.endIndentOnePixel
          : dividerParams.endIndent,
      color: (dividerParams.color == null)
          ? MediumGreyThemeData().highlightColor
          : dividerParams.color,
    );
  }
}
