import 'package:flutter/material.dart';
import '../widgets/custom-icon.dart';
import '../../theme/theme.dart';
import '../../utils/consts.dart';
import '../widgets/custom-image.dart';

/*This widget is used to display a Grid View.
    The grid view comprises cards, that contain a header, a sub-widget, and a label.
    The individual cards can be tapped or long-pressed to perform certain functions.
    The user can also specify the cross axis count and the callback functions.

    SAMPLE IMPLEMENTATION:
    ImageData imageobj= new ImageData("http://images.unsplash.com/photo-1499084732479-de2c02d45fcc?ixlib=rb-1.2.1&ixid=eyJhcHBfaWQiOjEyMDd9&auto=format&fit=crop&w=889&q=80",400.0,300.0);
    Area Obj1 = new Area("Image Title", CustomisedImage(imageobj),"The beautiful night");

    IconState icon =new IconState(Icons.beach_access, Colors.blue,36.0);
    Area Obj2 = new Area("Icon Title", CustomisedIcon(icon), "Blue Umbrella Icon");
    AreaList.add(Obj1);
    AreaList.add(Obj2);

    onclickGrid(int nIndex, String sText) {
      print(nIndex);
      print(sText);
    }
    onLongPressGrid(int nIndex, String Text1, String Text2) {
      print(nIndex);
      print(Text1);
      print(Text2);
    }
    Grid gridobj=new Grid(2,onclickGrid,onLongPressGrid);
    Center(
              child: CustomisedGridView(AreaList, gridobj)
    */

//AUTHOR : Soumyadeep Mitra

//WIDGET IMPLEMENTATION
Widget CustomisedGridView(List<Area> area, Grid gridobj) {
  return Container(
    child: new GridView.builder(

      itemCount: area.length,
      gridDelegate: new SliverGridDelegateWithFixedCrossAxisCount(
          crossAxisCount: gridobj.count),
      itemBuilder: (BuildContext context, int index) {

        return InkWell(
          onTap: (){gridobj.callback(index,area[index].header);} ,
          onLongPress: (){gridobj.longcallback(index,area[index].header,area[index].label);} ,

          child: new Card(
            color: YellowThemeData().backgroundColor,
            child: Column(
              children: <Widget>[
                SizedBox(height: heightTen),
                new Center(
                    child: Text(area[index].header, style: TextStyle(color: Colors.black, fontSize:font_small ,fontWeight: FontWeight.bold),)),
                Expanded(child: Container(child: area[index].widget)),
                new Center(
                  child: Text(area[index].label),
                ),
                SizedBox(height: heightTen),
              ],
            ),
          ),
        );
      },
    ),
  );
}

//Sub-Widget model Definition
class Area {
  String header;
  Widget widget;
  String label;

  Area(this.header, this.widget, this.label);
}
//Grid model Definition
class Grid {
  int count;
  final void Function(int, String) callback;
  final void Function(int, String, String) longcallback;
  Grid(this.count, this.callback, this.longcallback);
}



