/*
Description:
A loader or progress bar that can be used to indicate the completeness of something or act as a splash/wait page or element.
There are two types of Linear Progress Bars: Definite and Indefinite
- Indefinite progress bars are indefinitely moving bars that can be used to showcase progress without any particular values.
- Defintie progress bars intake a value and show the progress accordingly. For example, 0.6 will show a bar that is 60% complete.

Usage:
The user can pass in parameters to the widget like value color, background color, custom animator etc.
See CustomLinearProgressBarParameters for more information.
    
    Please Note: 
    value = 0 or value = null will create an indefinte Linear Progress bar

    CustomLinearProgressBarParameters linearBarParameters = new CustomLinearProgressBarParameters(value: 0, backgroundColor: Colors.red, valueColor: Colors.white)
    CustomLinearProgressBarIndicator(linearBarParameters);

Author:
Rishabh Thakur
*/

import 'package:flutter/material.dart';
import 'package:flutter_widgets_library/theme/theme.dart';
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'package:flutter_widgets_library/utils/consts.dart' as cons;

Widget CustomLinearProgressBarIndicator(CustomLinearProgressBarParameters linearBarParams) {
    // If no parameters are passed as a part of the widget call
    if(linearBarParams == null){
      return Container(
              padding: cons.edgeInsetValues,
              child: LinearProgressIndicator(
                value: cons.intialValue,
                backgroundColor: MediumGreyThemeData().backgroundColor,
                valueColor: new AlwaysStoppedAnimation<Color>(
                  MediumGreyThemeData().accentColor),
              ),
      );
    }
    else {
    // If all or limited parameters are passed as part of the parameters
    return Container(
          padding: cons.edgeInsetValues,
          child: LinearProgressIndicator(
            value: (linearBarParams.value == 0 || linearBarParams.value == null)
                ? null
                : linearBarParams.value, // If value is null or 0, the bar is non-definite, else it will take the value
            backgroundColor: (linearBarParams.backgroundColor!=null)?linearBarParams.backgroundColor:MediumGreyThemeData().backgroundColor,
            valueColor: (linearBarParams.valueColor!=null)?linearBarParams.valueColor:new AlwaysStoppedAnimation<Color>(
                MediumGreyThemeData().accentColor),
          ),
    );
    }
}