/*
Description:
A widget that dynamically creates a tile view using List Tiles for a list of incoming data.
The widget accepts a title, subtitle, leading and trailing icons for each list tile along.


Usage:
The user can pass in a list of TileData that includes title, subtitle, trailing and leading widgets.
The user can also pass on parameters like density, isThreeLine, padding etc.
See TileData and ListTileParameters class definitons for more information.
The user also passes a callback function which is invoked when a tile is Tapped or Long Pressed. 
- The widget returns the index value and the title of that particular tile.
    
    List<TileData> tileItems = [...];
    ListTileParameters tileParameters = new ListTileParameters(dense: true, isThreeLine: true);
    CustomListTileGeneric(tileItems, tileParameters, callback);

Author:
Rishabh Thakur
*/

import 'package:flutter/material.dart';
import 'package:flutter_widgets_library/utils/consts.dart' as consts;
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'package:quiver/iterables.dart';

Widget CustomListTileGeneric(List<TileData> listTileData, ListTileParameters listTileParams,
    Function(int, String) callback) {
  if (listTileData == null || listTileData.length == 0 || listTileParams == null) {
    return Column(
      children: <Widget>[
        ListTile(
          trailing: Icon(consts.icon1),
          title: Text(consts.listTitle),
          subtitle: Text(consts.listSubtitle),
          leading: Icon(consts.icon1),
        ),
        ListTile(
          trailing: Icon(consts.icon1),
          title: Text(consts.listTitle),
          subtitle: Text(consts.listSubtitle),
          leading: Icon(consts.icon1),
        )
      ],
    );
  } else {
    return SingleChildScrollView(
        child: Column(
            children: enumerate(listTileData)
                .map((key) => (ListTile(
                      leading: key.value.leading,
                      title: Text(key.value.title),
                      subtitle: Text(key.value.subtitle),
                      trailing: key.value.trailing,
                      isThreeLine: (listTileParams.isThreeLine != null)
                          ? listTileParams.isThreeLine
                          : false,
                      dense: (listTileParams.dense != null) ? listTileParams.dense : false,
                      onTap: () {
                        return callback(key.index, key.value.title);
                      },
                      onLongPress: () {
                        return callback(key.index, key.value.title);
                      },
                      enabled: (key.value.enabled != null)
                          ? key.value.enabled
                          : true,
                      selected: (key.value.selected != null)
                          ? key.value.selected
                          : false,
                    )))
                .toList()));
  }
}
