/*
Description:
A widget that creates a custom TextField in which the user can input.

Usage:
The user can pass in  maximum length and obsecure property of the text field .
The user can also pass on parameters like box decoration, prefix icon, fill colour etc.
See CustomTextFieldContents and CustomTextFieldParameters class definitons for more information.
The user also passes a callback function which is invoked when the TextField is used.
- The widget returns the entered text when submitted.

    TextFieldContents textFieldObj = new TextFieldContents(15, true, true);
    TextFieldParameters finalObj = new TextFieldParameters(decoration: InputDecoration( prefixIcon: Icon(...), filled: true, fillColor: .., border: ...));
    CustomTextField(data: textFieldObj, params: finalObj, callbackTextfield: onTextSubmitCallback);

Author:
Anubhav Sinha
*/


import 'dart:ui';
import 'package:flutter_widgets_library/theme/theme.dart';
import 'package:flutter/material.dart';
import 'package:flutter_widgets_library/utils/consts.dart' as cons;
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';


class CustomTextField extends StatefulWidget {

  final TextFieldParameters params;
  final TextFieldContents data;
  final void Function(String) callbackTextfield;

  const CustomTextField({
    Key key,

    @required this.data,
    this.params,
    this.callbackTextfield

  }) :
        super(key: key);
  @override
  _CustomTextFieldState createState() => _CustomTextFieldState(
      this.params,
      this.data,
      this.callbackTextfield
  );
}
class _CustomTextFieldState extends State<CustomTextField> {
  TextFieldParameters params;
  TextFieldContents data;
  void Function(String) callbackTextfield;
  _CustomTextFieldState(
      TextFieldParameters params,
      TextFieldContents data,
      Function(String) callbackTextfield,
      ){
    this.params = params;
    this.data = data;
    this.callbackTextfield = callbackTextfield;
  }
  String change = '';
  final TextEditingController _textEditingControl = new TextEditingController();
  @override
  Widget build(BuildContext context) {
    if (params != null && data != null){
      return TextField(
        controller: _textEditingControl,
        maxLength: (data.maximum_length != null)? data.maximum_length : cons.MAX_Length,
        maxLengthEnforced: (data.maximum_length_enforced != null)? data.maximum_length_enforced : cons.MAX_Length_Enforced,
        obscureText: (data.obsecure_text != null)? data.obsecure_text : cons.OBSECURE_Text,
        cursorColor: (params.cursorColor != null)? params.cursorColor : MediumGreyThemeData().cursorColor,
        //autofocus: true,
        decoration: (params.decoration != null)? params.decoration: InputDecoration(
          //prefixIcon: Icon(Icons.search),
          //filled: true,
          //fillColor: PwCMediumGreyThemeData().primaryColor,
          border: OutlineInputBorder(
              borderRadius: BorderRadius.circular(cons.padding_value2),
              borderSide: BorderSide(
                color: StartupTheme().hintColor,

              )
          ),
        ),
        onChanged: (String temp) {
          setState(() {
            change = temp;
          });
          //print(e);
        },

        onSubmitted: (String temp){
          setState(() {
            change= temp;
          });
          callbackTextfield(temp);
        },
        //onSubmitted: _submission,
      );
    }//if
    else{
      return TextField(
        controller: _textEditingControl,
        maxLength: cons.MAX_Length,
        maxLengthEnforced: cons.MAX_Length_Enforced,
        obscureText: cons.OBSECURE_Text,
        cursorColor: MediumGreyThemeData().cursorColor,
        autofocus: false,
        decoration: InputDecoration(
          border: OutlineInputBorder(
              borderRadius: BorderRadius.circular(cons.padding_value2),
              borderSide: BorderSide(
                color: StartupTheme().hintColor,
              )
          ),
        ),
        style: TextStyle(color: StartupTheme().hintColor),
        onChanged: (String temp) {
          setState(() {
            change = temp;
          });
          //print(e);
        },
        onSubmitted: (String temp){
          setState(() {
            change= temp;
          });
          print(temp);
        },

      );
    }
  }
}


