/*
Description:
A widget that creates an Alert Dialog Box dynamically along with clickable Flat Buttons.
This Dialog box can come in handy when a user needs to be prompted or double-checked about any action before progressing to the next Route.
The default Implementation of this widget when the user doesn't pass any value to the widget gives an Alert Dialog box along with two buttons 'Yes' or 'No'.

Usage:
The user can pass in Flat Buttons, Title of the Alert and the content that is supposed to be displayed.
The user can also pass on parameters like border radius, padding, shadow elevation etc.
See AlertDialogContents and AlertDialogParameters class definitons for more information.
The user also passes a callback function which is invoked when the Alert Dialog box is used.

  AlertDialogContents alertObj1 = new AlertDialogContents(FlatButton(...),FlatButton(...),"Alert Dialog Box Content ", Text("Alert Title"));
  AlertDialogParameters alertobj2 = new AlertDialogParameters(shape: RoundedRectangleBorder(...), backgroundColor: ..., elevation: 30);
  customAlertDialog(alertObj1, alertobj2, callback)

Author:
Anubhav Sinha
*/

import 'package:flutter/material.dart';
import 'package:flutter_widgets_library/theme/theme.dart';
import 'package:flutter_widgets_library/utils/consts.dart' as cons;
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import '../../theme/theme.dart';
import 'custom-FlatButton.dart';
import 'custom-divider.dart';

import '../../theme/theme.dart';


Widget customAlertDialog( AlertDialogContents samp_content, AlertDialogParameters param, Function(String) callbackAlert, FlatButtonParameters button1, [FlatButtonParameters button2]){
  if(samp_content != null && param != null) {
    return FractionallySizedBox(
      heightFactor: cons.height_factor1,
      widthFactor: cons.width_factor1,
      child: AlertDialog(
        title: samp_content.title,
        content: Text(samp_content.Content),
        actions: <Widget>[
          CustomFlatButton(button1),
          CustomFlatButton(button2),
        ],
        shape: param.shape,
        elevation: (param.elevation != null)? param.elevation: 30,
        backgroundColor: (param.backgroundColor != null)? param.backgroundColor: MediumGreyThemeData().backgroundColor,
        contentTextStyle: TextStyle(
            fontSize: cons.font_size2, color: MediumGreyThemeData().primaryColorDark),

      ),
    );
  }//if
  else{
    return FractionallySizedBox(
      heightFactor: cons.height_factor1,
      widthFactor: cons.width_factor1,
      child: AlertDialog(
        content: Text(cons.dialogContent),
        actions:[
          FlatButton(
            child: Text(cons.DIALOG_BUTTON_T1,style: TextStyle(color: MediumGreyThemeData().primaryColorDark),),

            onPressed: (){
              return callbackAlert(cons.DIALOG_BUTTON_T1);
            },
          ),
          FlatButton(
            child: Text(cons.DIALOG_BUTTON_T2,style: TextStyle(color: MediumGreyThemeData().primaryColorDark),),
            onPressed: (){
              return callbackAlert(cons.DIALOG_BUTTON_T2);
            },
          )
        ],
        backgroundColor: MediumGreyThemeData().primaryColor,
        contentTextStyle: TextStyle(fontSize: cons.font_size2, color: MediumGreyThemeData().primaryIconTheme.color),
      ),
    );
  }
}
