/*
Description:
A widget that creates a custom Slider that user can drag to input a numerical value within the specified range.
It also has divisions which divides the line into equal parts for easier sliding.

Usage:
The user can pass in  maximum value, minimum value and number of divisions of the slider .
The user can also pass on parameters like box active track colour and inactive track colour etc.
See CustomSliderContents and CustomSliderParameters class definitons for more information.
The user also passes a callback function which is invoked when the Slider is used.
- The widget returns the current value of the slider.

    SliderContents sliderObj = new SliderContents(10, 100.0, 0.0, Colors.yellow);
    SliderParameters finalObject = new SliderParameters(inactiveColor: Colors.red);
    CustomSlider(param: finalObject, data: sliderObj, callbackSlider: onSlideCallback);

Author:
Anubhav Sinha
*/

import 'dart:core';
import 'package:flutter/material.dart';
import 'package:flutter_widgets_library/theme/theme.dart';
import 'package:flutter_widgets_library/utils/consts.dart' as cons;
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';

class CustomSlider extends StatefulWidget {

  final SliderParameters param;
  final SliderContents data;
  final void Function(double) callbackSlider;
  const CustomSlider({
    Key key,

    @required this.data,
    this.param,
    this.callbackSlider

  }) :
        super(key: key);
  @override
  _CustomSliderState createState() => _CustomSliderState(
      this.param,
      this.data,
      this.callbackSlider
  );
}
class _CustomSliderState extends State<CustomSlider> {
  SliderParameters param;
  SliderContents data;
  void Function(double) callbackSlider;
  _CustomSliderState(
      SliderParameters param,
      SliderContents data,
      Function(double) callbackSlider
      ){
    this.param = param;
    this.data = data;
    this.callbackSlider = callbackSlider;

  }
  double _value = 0.0;
  //print();
  @override
  Widget build(BuildContext context) {
// TODO: implement build
    if (param == null && data == null ) {
      return Slider(
        divisions: cons.DIVS,
        min: cons.MIN,
        max: cons.MAX,
        activeColor: MediumGreyThemeData().primaryColor,
        //inactiveColor: PwCMediumGreyThemeData().primaryColorDark,
        value: _value,
        onChanged: (value) {
          setState(() {
            _value = value;
          });
          callbackSlider(_value);
        },
      );
    } //if
    else{
      return Slider(
        divisions: data.divs,
        max: data.maximum,
        min: data.minimum,
        activeColor: data.colorActive,
        inactiveColor: (param.inactiveColor != null)? param.inactiveColor: MediumGreyThemeData().primaryColor,
        //inactiveColor: PwCMediumGreyThemeData().primaryColorDark,
        value: _value,
        onChanged: (value) {
          setState(() {
            _value = value;
          });
          callbackSlider(_value);
        },
      );

    }
  }
}