/*
Description:
A widget that creates a custom toggle button or a switch button of boolean type.

Usage:
The user can pass in colour of the button when active and the colour of the track when the button is active.
The user can also pass on parameters like inactive track .
See CustomTextFieldContents and CustomTextFieldParameters class definitons for more information.
The user also passes a callback function which is invoked when the TextField is used.
- The widget returns the state of the switch i.e true or false when submitted.

    SwitchContents switchobj = new SwitchContents(MediumGreyThemeData().toggleableActiveColor, MediumGreyThemeData().toggleableActiveColor);
    SwitchParameters finalObj = new SwitchParameters(inactiveTrackColor: Color.fromRGBO(200, 0, 0, 0.5));
    CustomSwitch(data: switchobj, param: finalObj, callbackSwitch: onSwicthTapCallback)

Author:
Anubhav Sinha
*/

import 'package:flutter/material.dart';
import 'package:flutter_widgets_library/theme/theme.dart';
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';

class CustomSwitch extends StatefulWidget {

  final SwitchParameters param;
  final SwitchContents data;
  final void Function(bool) callbackSwitch;

  const CustomSwitch({
    Key key,

    @required this.data,
    this.param,
    this.callbackSwitch

  }) :
        super(key: key);
  @override
  _CustomSwitchState createState() => _CustomSwitchState(
      this.param,
      this.data,
      this.callbackSwitch
  );
}
class _CustomSwitchState extends State<CustomSwitch> {
  SwitchParameters param;
  SwitchContents data;
  void Function(bool) callbackSwitch;
  _CustomSwitchState(
      SwitchParameters param,
      SwitchContents data,
      Function(bool) callback
      ){
    this.param = param;
    this.data = data;
    this.callbackSwitch = callback;
  }
  bool val= false;
  @override
  Widget build(BuildContext context) {
// implement build
    if (param == null && data == null){
      return Switch(
        activeColor: MediumGreyThemeData().primaryColor,
        activeTrackColor: MediumGreyThemeData().primaryColor,
        value: val,
        onChanged: (bool e) => something(e) ,
        inactiveTrackColor: MediumGreyThemeData().primaryColorDark,
      );
    }
    else {
      return Switch(
        activeColor: data.color_active,
        activeTrackColor: data.color_active_track,
        value: val,
        onChanged: (bool e) => something(e) ,
        inactiveTrackColor: (param.inactiveTrackColor != null)? param.inactiveTrackColor: MediumGreyThemeData().primaryColorDark,
      );
    }

  }
  void something(bool e){
    setState(() {
      if (e) {
        val=true;
        e=true;
      }
      else {
        val=false;
        e=false;
      }
      callbackSwitch(val);
    });
  }
}
