import 'package:flutter/material.dart';
import 'package:flutter_widgets_library/models/expandable-panel-model.dart';
import 'package:flutter_widgets_library/theme/theme.dart';
import 'package:flutter_widgets_library/utils/consts.dart';

Widget expansionPanelWidget(List<ExpandablePanelData> data) {
  return Container(
    child: ListView.builder(
      itemBuilder: (BuildContext context, int index) => EntryItem(data[index]),
      itemCount: data.length,
    ),
  );
}

// Displays one Entry. If the entry has children then it's displayed
// with an ExpansionTile.
Widget EntryItem(ExpandablePanelData root) {
  if (root.children.isEmpty)
    return ListTile(
        title: Text(
      root.title,
      overflow: TextOverflow.ellipsis,
    ));
  return Card(
      child: Theme(
    data: ThemeData(
        unselectedWidgetColor: MediumGreyThemeData().unselectedWidgetColor,
        accentColor: MediumGreyThemeData().highlightColor),
    child: ExpansionTile(
//      backgroundColor: MediumGreyThemeData().backgroundColor,
      key: PageStorageKey<ExpandablePanelData>(root),
      title: Text(
        root.title,
        overflow: TextOverflow.ellipsis,
      ),
      children: root.children.map(CardWidget).toList(),
      leading: root.icon,
    ),
  ));
}

Widget CardWidget(ExpandablePanelChildrenData widgetdata) {
  return GestureDetector(
      onTap: () {
        widgetdata.callback(1, widgetdata.title);
      },
      child: Container(
        decoration: BoxDecoration(
            color: MediumGreyThemeData().backgroundColor,
            boxShadow: [
              BoxShadow(
                color: MediumGreyThemeData().highlightColor,
                blurRadius: heightFive,
              )
            ]),
        child: ListTile(
          title: Text(widgetdata.title),
        ),
      ));
}
