import 'package:flutter/material.dart';
import 'package:flutter_widgets_library/theme/theme.dart';
import 'package:flutter_widgets_library/utils/consts.dart' as constants;
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';

Widget featureCard(FeaturedCardData data) {
  return Container(
    height: data.containerHeight != null
        ? data.containerHeight
        : constants.heightFourHundred,
    width: data.containerWidth != null
        ? data.containerWidth
        : constants.heightThreeHundred,
    decoration: BoxDecoration(
      color: LiteThemeData().backgroundColor,
      border: Border.all(
        color: MediumGreyThemeData().primaryColorDark,
        width: constants.heightOne,
      ),
      borderRadius:
      BorderRadius.circular(constants.heightFive * constants.heightThree),
    ),
    child: Padding(
      padding: EdgeInsets.all(constants.heightTwenty),
      child: SingleChildScrollView(
        child: Column(
          children: <Widget>[
            SizedBox(
              height: constants.heightThirty,
            ),
            Visibility(
              visible: data.iconVisibility ? false : true,
              child: Material(
                  type: MaterialType
                      .transparency, //Makes it usable on any background color, thanks @IanSmith
                  child: Ink(
                    decoration: BoxDecoration(
                      border: Border.all(
                          color: MediumGreyThemeData().highlightColor,
                          width: constants.heightTwentyFive),
                      color: MediumGreyThemeData().iconTheme.color,
                      shape: BoxShape.circle,
                    ),
                    child: InkWell(
                      //This keeps the splash effect within the circle
                      borderRadius: BorderRadius.circular(constants
                          .heightHundred *
                          constants
                              .heightTen), //Something large to ensure a circle
                      child: Padding(
                        padding: EdgeInsets.all(constants.heightTwenty),
                        child: CircleAvatar(
                          radius: constants.heightThirty + constants.heightFive,
                          backgroundImage: AssetImage(data.imgPath != null
                              ? data.imgPath
                              : constants.cardImagePath),
                        ),
                      ),
                    ),
                  )),
            ),
            Visibility(
              visible:
              data.iconVisibility != null ? data.iconVisibility : false,
              child: Material(
                  type: MaterialType
                      .transparency,
                  child: Ink(
                    decoration: BoxDecoration(
                      border: Border.all(
                          color: LiteThemeData().iconTheme.color,
                          width: constants.heightTwentyFive),
                      color: LiteThemeData().buttonColor,
                      shape: BoxShape.circle,
                    ),
                    child: InkWell(
                      //This keeps the splash effect within the circle
                      borderRadius: BorderRadius.circular(constants
                          .heightHundred *
                          constants
                              .heightTen), //Something large to ensure a circle
                      child: Padding(
                        padding: EdgeInsets.all(constants.heightTwenty),
                        child: data.icon != null
                            ? data.icon
                            : Icon(
                          Icons.message,
                          size: constants.heightFourrty,
                          color: LiteThemeData().iconTheme.color,
                        ),
                      ),
                    ),
                  )),
            ),
            SizedBox(
              height: constants.heightThirty,
            ),
            Text(
              data.title != null ? data.title : constants.dialogHeader,
              style: TextStyle(
                color: LiteThemeData().buttonColor,
                fontSize: constants.heightThirty,
              ),
              textAlign: TextAlign.center,
              overflow: TextOverflow.ellipsis,
            ),
            SizedBox(
              height: constants.heightTwenty,
            ),
            Text(
              data.bodyText != null ? data.bodyText : constants.dialogHeader,
              style: TextStyle(
                color: MediumGreyThemeData().primaryColorDark,
                fontSize: constants.heightTwenty,
              ),
              textAlign: TextAlign.center,
              softWrap: true,
              maxLines: constants.intTwo * constants.intTwo,
              overflow: TextOverflow.ellipsis,
            ),
            SizedBox(
              height: constants.heightFourrty,
            ),
            Text(
              data.footerText != null
                  ? data.footerText
                  : constants.dialogHeader,
              style: TextStyle(
                color: MediumGreyThemeData().primaryColorDark,
                fontSize: constants.heightTwenty,
              ),
              textAlign: TextAlign.center,
              overflow: TextOverflow.ellipsis,
            ),
            SizedBox(
              height: constants.heightTwenty,
            ),
            ButtonBar(
              alignment: MainAxisAlignment.spaceBetween,
              children: <Widget>[
                SizedBox(
                  width: constants.heightHundred + constants.heightFifty,
                  height: constants.heightThirty + constants.heightFive,
                  child: RaisedButton(
                    color: LiteThemeData().backgroundColor,
                    child: Text(
                      data.secondBtnText != null
                          ? data.secondBtnText
                          : constants.cardBtnText,
                      style: TextStyle(fontSize: constants.fontMedium,color: LiteThemeData().buttonColor),
                      overflow: TextOverflow.ellipsis,
                      maxLines: constants.intOne,
                    ),
                    shape: RoundedRectangleBorder(
                        borderRadius:
                        BorderRadius.circular(constants.fontMedium),
                        side: BorderSide(
                            color: LiteThemeData().primaryColor)),
                    onPressed: null,
                  ),
                ),
                SizedBox(
                  width: constants.heightHundred + constants.heightFifty,
                  height: constants.heightThirty + constants.heightFive,
                  child: RaisedButton(
                    color: Colors.green,
                    child: Text(
                      data.firstBtnText != null
                          ? data.firstBtnText
                          : constants.cardBtnText,
                      style: TextStyle(fontSize: constants.fontMedium,color: LiteThemeData().buttonColor),
                      overflow: TextOverflow.ellipsis,
                      maxLines: constants.intOne,
                    ),
                    shape: RoundedRectangleBorder(
                        borderRadius:
                        BorderRadius.circular(constants.fontMedium),
                        side: BorderSide(
                            color: LiteThemeData().primaryColor)),
                    onPressed: null,
                  ),
                ),
              ],
            ),
            Divider(
              thickness: constants.heightFive,
              color: MediumGreyThemeData().iconTheme.color,
            ),
            ButtonBar(
              alignment: MainAxisAlignment.center,
              children: <Widget>[
                RaisedButton(
                  color: LiteThemeData().buttonColor,
                  padding: EdgeInsets.only(
                      left: constants.heightFourrty,
                      right: constants.heightFourrty),
                  child: Text(
                    data.btnText != null ? data.btnText : constants.cardBtnText,
                    style: TextStyle(
                        fontSize: constants.fontMedium,
                        color: LiteThemeData().backgroundColor),
                  ),
                  onPressed: null,
                  shape: RoundedRectangleBorder(
                    borderRadius: BorderRadius.circular(constants.fontMedium),
                  ),
                ),
              ],
            ),
          ],
        ),
      ),
    ),
  );
}
