import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_widgets_library/theme/theme.dart';
import 'package:flutter_widgets_library/utils/consts.dart' as constants;
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';

Widget materialCardWidget(
    MaterialCardData data, void Function(int, String) callback) {
  return Padding(
    padding: EdgeInsets.all(constants.heightThirty),
    child: Container(
      decoration: BoxDecoration(
        boxShadow: [
          BoxShadow(
              color: MediumGreyThemeData().backgroundColor,
              blurRadius: constants.heightTen,
              offset: Offset.zero)
        ],
        borderRadius: BorderRadius.circular(constants.heightFive),
        color: MediumGreyThemeData().primaryColor,
      ),
      height: constants.heightFourHundred,
      width: (data.width != null) ? data.width : constants.heightThreeHundred,
      child: SingleChildScrollView(
        child: Container(
          child: Column(
            children: <Widget>[
              Card(
                child: Container(
                  height: constants.heightOneEighty,
                  decoration: BoxDecoration(
                    image: DecorationImage(
                        image: AssetImage(
                          (data.imgPath != null)
                              ? data.imgPath
                              : constants.cardImagePath,
                        ),
                        fit: BoxFit.fill),
                  ),
                ),
              ),
              ListTile(
                leading: Icon(
                  data.icon != null ? data.icon : Icons.home,
                  size: constants.heightFifty,
                  color: MediumGreyThemeData().highlightColor,
                ),
                title: Text(
                  (data.title != null) ? data.title : constants.cardTitle,
                  style: TextStyle(
                    color: MediumGreyThemeData().primaryColorDark,
                    fontSize: constants.fontLarger,
                    fontWeight: constants.fontBold,
                  ),
                  overflow: TextOverflow.ellipsis,
                ),
                contentPadding: EdgeInsets.all(constants.heightTwenty),
                subtitle: Text(
                  (data.subtitle != null)
                      ? data.subtitle
                      : constants.cardSubtitle,
                  style: TextStyle(
                    color: MediumGreyThemeData().primaryColorDark,
                    fontSize: constants.fontMedium,
                    fontWeight: constants.fontBold,
                  ),
                  overflow: TextOverflow.ellipsis,
                  maxLines: 3,
                  softWrap: true,
                ),
              ),
              ButtonBar(
                children: <Widget>[
                  RaisedButton(
                    color:
                        MediumGreyThemeData().tabBarTheme.unselectedLabelColor,
                    child: Text(
                      data.btnText != null ? data.btnText : "See More",
                      style: TextStyle(fontSize: constants.fontMedium),
                    ),
                    onPressed: () => {
                      callback(1, "Button text")},
                  ),
                ],
              ),
            ],
          ),
        ),
      ),
    ),
  );
}
